<?php
/**
 * @file
 * wrappers for zend functions and direct interraction with google apis
 * 
 */

$inc_path = get_include_path();
if (!in_array(dirname(__FILE__), split(PATH_SEPARATOR, $inc_path))) {
 set_include_path(dirname(__FILE__) . PATH_SEPARATOR . $inc_path);
}

/**
 * @see Zend_Loader
 */
require_once 'Zend/Loader.php';
//include(libraries_get_path($name) . '/library/Zend/Loader.php');



/**
 * @see Zend_Gdata
 */
Zend_Loader::loadClass('Zend_Gdata', dirname(__FILE__));

/**
 * @see Zend_Gdata_AuthSub
 */
Zend_Loader::loadClass('Zend_Gdata_AuthSub', dirname(__FILE__));

/**
 * @see Zend_Gdata_ClientLogin
 */
Zend_Loader::loadClass('Zend_Gdata_ClientLogin', dirname(__FILE__));

/**
 * @see Zend_Gdata_Docs
 */
Zend_Loader::loadClass('Zend_Gdata_Docs', dirname(__FILE__));
/**
 * Restore include_path
 */


Zend_Loader::loadClass('Zend_Http_Client', dirname(__FILE__));
Zend_Loader::loadClass('Zend_Gdata_Gapps', dirname(__FILE__));

/**
 * Returns a HTTP client object with the appropriate headers for communicating 
 * with Google using the ClientLogin credentials supplied.
 *
 * @param $user
 *   A string that is the username, in e-mail address format, to authenticate
 * @param $pass
 *   string that is the password for the user specified
 *   
 * @return
 *     Zend_Http_Client returns a client object 
 */
function droogle_get_client_login_http_client($user, $pass) {
 $service = Zend_Gdata_Docs::AUTH_SERVICE_NAME;
 $client = Zend_Gdata_ClientLogin::getHttpClient($user, $pass, $service);
 return $client;
}

/*
 * prints google docs list output in an unordered list
 * 
 * @param object $feed
 *   an object with the google document list info, titles, document types, etc
 * @param boolean $html
 *   boolean deciding if to print a text list or html formatted list of google docs
 *   
 * @param string $content
 *   a string is returned with the content to print to the screen
 */
function droogle_print_documents_feed($feed, $html) {
 //print_r($feed);
 try {
  $content = "";
  if ($html) {
   $content = "<ul>\n";
  }

  // Iterate over the document entries in the feed and display each document's
  // title.
  foreach ($feed->entries as $entry) {

   if ($html) {
    // Find the URL of the HTML view of the document.
    $alternateLink = '';
    foreach ($entry->link as $link) {
     if ($link->getRel() === 'alternate') {
      $alternateLink = $link->getHref();
     }
    }
    // Make the title link to the document on docs.google.com.
    $content .= "<li><a href=\"$alternateLink\">\n";
   }

   $content .= "$entry->title\n";

   if ($html) {
    $content .= "</a></li>\n";}
  }
 } catch (Exception $e) {
  drupal_set_message("Error: Unable to process.\n" . check_plain($e->getMessage()));
  //echo phpinfo();

 }
 return $content;
}

/*
 * API wrapper to upload document to a google docs account
 * 
 * @param string $user
 *   string with the google user name
 * @param string $password
 *   string with the google password for the account
 * @param object $docs
 *   an object with the google docs client info already authenticated
 * @param boolean $html
 *   boolean and if TRUE then function will return html rather than text
 * @param string $originalFileName
 *   string with the files name that will be uploaded
 * @param string $temporaryFileLocation
 *   string with where the file is stored on the local file system
 * 
 * @return string
 *   a string is returned with either an error message or the message Success ... return is just used for debugging
 * 
 */
function droogle_upload_document($user, $password, $docs, $html, $originalFileName, $temporaryFileLocation) {
 $content = 'got to uploadDocumemt';
 try{
  $fileToUpload = $originalFileName;
  if ($temporaryFileLocation) {
   $fileToUpload = $temporaryFileLocation;
  }

  // Upload the file and convert it into a Google Document. The original
  // file name is used as the title of the document and the MIME type
  // is determined based on the extension on the original file name.
  $filenameParts = explode('.', $temporaryFileLocation);
  $fileExtension = end($filenameParts);

  //drupal_set_message($fileExtension);
  $mimeType = Zend_Gdata_Docs::lookupMimeType($fileExtension);
  //$mimeType = Zend_Gdata_Docs::lookupMimeType($fileExtension);
  //$mimeType = Zend_Gdata_Docs::lookupMimeType($fileExtension);
  //drupal_set_message('mimetype is '.$mimeType);
  $newDocumentEntry = $docs->uploadFile($fileToUpload, $originalFileName, $mimeType, Zend_Gdata_Docs::DOCUMENTS_LIST_FEED_URI);

  if ($html) {
   // Find the URL of the HTML view of this document.
   $alternateLink = '';
   foreach ($newDocumentEntry->link as $link) {
    if ($link->getRel() === 'alternate') {
     $alternateLink = $link->getHref();
    }
   }
   // Make the title link to the document on docs.google.com.
   //drupal_set_message('<a href=\"$alternateLink\">\n');
  }
  //echo $newDocumentEntry->title . "\n";

  $content = "Success";
  return $content;
 } catch (Exception $e) {
  return "Error: Unable to process.\n" . $e->getMessage();
  //return 'error';
 }


}

/*
 * adds a permission to a google docs file
 * 
 * TODO:  drupal_development@babson.edu is hard coded right now on line 213.  This api function is not currently used by the module but shows usage
 *     these are notes for my future use as wel
 * 
 * @param string $document_id
 *   string with the google document id
 * @param string $user
 *   the user to add permissions for
 *   
 */
function droogle_add_permission($document_id = '1mKjGghPEU2hfcoU82gPPXT2G0wkBPrIQtPch01-X3BA', $user = 'drupal_development@babson.edu') {
 //To share a collection, provide a collection resource ID instead of a document ID
 //http://code.google.com/apis/documents/docs/3.0/developers_guide_protocol.html#ACLSharingCollections
 $clientAcl = droogle_get_client_login_http_client('username@domain.edu', 'password');
 //$user = 'drupal_development@babson.edu';
 $method = 'POST';
 $headers['GData-Version'] = '3.0';
 $contenttype = 'application/atom+xml';

 //This url can be hardcoded or, as in this example, can be dynamically run via a var $docId and $user for sharing
 //$aclUrl = 'http://docs.google.com/feeds/default/private/full/spreadsheet%3A' . $docId . '/acl';
 //$document_id = '1-qYaniUyBYDPNMIos2Rs60RPruYKv17qzRG8mjR-V88';
 //$document_id = '1mKjGghPEU2hfcoU82gPPXT2G0wkBPrIQtPch01-X3BA';  //get this id by clicking on a url on the droogle page and grab the document id

 //api guide:  http://code.google.com/apis/documents/docs/3.0/developers_guide_protocol.html
 //to share a collection http://code.google.com/apis/documents/docs/3.0/developers_guide_protocol.html#ACLSharingCollections
 //by default user will be emailed they have been granted access ... to suppress the email
 // use POST /feeds/default/private/full/document:12345/acl?send-notification-emails=false
 $aclUrl = "https://docs.google.com/feeds/default/private/full/" . $document_id . "/acl";

 $aclEntry = '<entry xmlns="http://www.w3.org/2005/Atom" xmlns:gAcl="http://schemas.google.com/acl/2007">';
 $aclEntry .= "<category scheme='http://schemas.google.com/g/2005#kind' term='http://schemas.google.com/acl/2007#accessRule'/>";
 $aclEntry .= "<gAcl:role value='writer'/>";

 $aclEntry .= "<gAcl:scope type='user' value='drupal_development@babson.edu'/>";
 $aclEntry .= "</entry>";

 $gdataAcl = new Zend_Gdata($clientAcl);

 try {
  $gdataAcl->performHttpRequest( $method, $aclUrl, $headers, $aclEntry, $contenttype );
 } catch (Zend_Gdata_App_Exception $ex) {
  // Report the exception to the user
  echo $ex->getMessage();
 }

}

/*
 * Creates a google docs collection
 *  
 *  @param string $folder_name
 *    a string with the name of the new folder
 *    
 *  @return string
 *    a string is returned showing if successful
 */
function droogle_create_collection($folder_name = "test_folder") {
 $clientAcl = droogle_get_client_login_http_client('username@domain.edu', 'password');
 //$user = 'drupal_development@babson.edu';
 $method = 'POST';
 $headers['GData-Version'] = '3.0';
 $contenttype = 'application/atom+xml';

 //This url can be hardcoded or, as in this example, can be dynamically run via a var $docId and $user for sharing
 //$aclUrl = 'http://docs.google.com/feeds/default/private/full/spreadsheet%3A' . $docId . '/acl';
 //$document_id = '1-qYaniUyBYDPNMIos2Rs60RPruYKv17qzRG8mjR-V88';
 //$document_id = '1mKjGghPEU2hfcoU82gPPXT2G0wkBPrIQtPch01-X3BA';  //get this id by clicking on a url on the droogle page and grab the document id

 //api guide:  http://code.google.com/apis/documents/docs/3.0/developers_guide_protocol.html
 //to share a collection http://code.google.com/apis/documents/docs/3.0/developers_guide_protocol.html#ACLSharingCollections
 //by default user will be emailed they have been granted access ... to suppress the email
 // use POST /feeds/default/private/full/document:12345/acl?send-notification-emails=false
 $Url = "https://docs.google.com/feeds/default/private/full";

 $Entry = '<entry xmlns="http://www.w3.org/2005/Atom" xmlns:gAcl="http://schemas.google.com/acl/2007">';
 $Entry .= "<category scheme='http://schemas.google.com/g/2005#kind' term='http://schemas.google.com/docs/2007#folder'/>";
 $Entry .= "<title type='text'>" . $folder_name . "</title>";

 $Entry .= "</entry>";

 $gdataAcl = new Zend_Gdata($clientAcl);

 try {
  $gdataAcl->performHttpRequest( $method, $Url, $headers, $Entry, $contenttype );
 } catch (Zend_Gdata_App_Exception $ex) {
  // Report the exception to the user
  echo $ex->getMessage();
 }
 //returning 0 indicates success.
 return 'folder was successfully created';

}

/*
 * adds a file already in the users google docs account to a google collection (folder)
 * 
 * @param string $collection_id
 *   string with the google collection id
 * @param string $document_id
 *   string with the google document id
 *   
 * @return string
 *   returns a string with text to indicate if successful
 */
function droogle_add_to_collection($collection_id = '0B-a-StXYm5kcZDE0YmExOGEtNDg3MS00M2UwLWE4YWItYTEzZjAxNjcyYjE0', $document_id = '1mKjGghPEU2hfcoU82gPPXT2G0wkBPrIQtPch01-X3BA') {
 $clientAcl = droogle_get_client_login_http_client('username@domain.edu', 'password');
 $method = 'POST';
 $headers['GData-Version'] = '3.0';
 $contenttype = 'application/atom+xml';

 //This url can be hardcoded or, as in this example, can be dynamically run via a var $docId and $user for sharing
 //$aclUrl = 'http://docs.google.com/feeds/default/private/full/spreadsheet%3A' . $docId . '/acl';
 //$document_id = '1-qYaniUyBYDPNMIos2Rs60RPruYKv17qzRG8mjR-V88';
 //$document_id = '1mKjGghPEU2hfcoU82gPPXT2G0wkBPrIQtPch01-X3BA';  //get this id by clicking on a url on the droogle page and grab the document id

 //api guide:  http://code.google.com/apis/documents/docs/3.0/developers_guide_protocol.html
 //to share a collection http://code.google.com/apis/documents/docs/3.0/developers_guide_protocol.html#ACLSharingCollections
 //by default user will be emailed they have been granted access ... to suppress the email
 // use POST /feeds/default/private/full/document:12345/acl?send-notification-emails=false
 $Url = "https://docs.google.com//feeds/default/private/full/folder%3A" . $collection_id . "/contents";

 $Entry = '<entry xmlns="http://www.w3.org/2005/Atom" xmlns:gAcl="http://schemas.google.com/acl/2007">';
 $Entry .= "<category scheme='http://schemas.google.com/g/2005#kind' term='http://schemas.google.com/docs/2007#folder'/>";
 $Entry .= "<id>https://docs.google.com/feeds/default/private/full/" . $document_id . "</id>";

 $Entry .= "</entry>";

 $gdataAcl = new Zend_Gdata($clientAcl);

 try {
  $gdataAcl->performHttpRequest( $method, $Url, $headers, $Entry, $contenttype );
 } catch (Zend_Gdata_App_Exception $ex) {
  // Report the exception to the user
  echo $ex->getMessage();
 }
 //returning 0 indicates success.
 return 'document was successfully added to the collection';
}

/*
 * prints out a list of google docs 
 * 
 * @param string $collection_id
 *   a string with the google collection id 
 * 
 * @result object
 *   returns a result object containing a google docs listing chock full of information about the document list
 */

function droogle_print_collection($collection_id = '0B-a-StXYm5kcNDEwZGQ2ZWItZGY2YS00YTk0LWIxYTUtMGJhZGRjNjU1NDA3') {  //happy_folder2 collection
 $clientAcl = droogle_get_client_login_http_client('username@domain.edu', 'password');
 $method = 'GET';
 $headers['GData-Version'] = '3.0';
 $contenttype = 'application/atom+xml';

 //This url can be hardcoded or, as in this example, can be dynamically run via a var $docId and $user for sharing
 //$aclUrl = 'http://docs.google.com/feeds/default/private/full/spreadsheet%3A' . $docId . '/acl';
 //$document_id = '1-qYaniUyBYDPNMIos2Rs60RPruYKv17qzRG8mjR-V88';
 //$document_id = '1mKjGghPEU2hfcoU82gPPXT2G0wkBPrIQtPch01-X3BA';  //get this id by clicking on a url on the droogle page and grab the document id

 //api guide:  http://code.google.com/apis/documents/docs/3.0/developers_guide_protocol.html
 //to share a collection http://code.google.com/apis/documents/docs/3.0/developers_guide_protocol.html#ACLSharingCollections
 //by default user will be emailed they have been granted access ... to suppress the email
 // use POST /feeds/default/private/full/document:12345/acl?send-notification-emails=false
 $Url = "https://docs.google.com//feeds/default/private/full/folder%3A" . $collection_id . "/contents";
 $Entry = NULL;
 $gdataAcl = new Zend_Gdata($clientAcl);

 try {
  $result = $gdataAcl->performHttpRequest( $method, $Url, $headers, $Entry, $contenttype );
 } catch (Zend_Gdata_App_Exception $ex) {
  // Report the exception to the user
  echo $ex->getMessage();
 }
 echo $result;
 //returning 0 indicates success.
 return $result;
}

/*
 * prints out an html list of google docs which goes through a drupal theme function
 * 
 * @param string $user
 *   string with the google username
 * @param string $password
 *   string with the google password
 * @param string $domain
 *   string with the domain of the google account
 * @param string $collection_id
 *   string with the google collection_id, just this collection will be printed out
 *   
 * @return string $content
 *   returns html in the $content variable
 * 
 */
function droogle_print_collection2($user=NULL, $password=NULL, $domain=NULL, $collection_id = '0B4mZRjHDl6MvZTA3NzBiMDctOTQ1NS00MGM5LWE2ZTUtNWYwZWYzMmJhMWI3') {  //happy_folder2 collection
 // Construct an HTTP POST request

 $clientlogin_url = "https://www.google.com/accounts/ClientLogin";

 $clientlogin_post = array(
    "accountType" => "HOSTED_OR_GOOGLE",
    "Email" => $user,
    "Passwd" => $password,
    "service" => "writely",
    "source" => "your application name"
    );

    // Initialize the curl object
    $curl = curl_init($clientlogin_url);
    // Set some options (some for SHTTP)

    curl_setopt($curl, CURLOPT_POST, TRUE);

    curl_setopt($curl, CURLOPT_POSTFIELDS, $clientlogin_post);

    curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_ANY);

    curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, FALSE);

    curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);



    // Execute

    $response = curl_exec($curl);

    //print $response;

    // Get the Auth string and save it

    preg_match("/Auth=([a-z0-9_\-]+)/i", $response, $matches);

    $auth = $matches[1];
    //echo "The auth string is: " . $auth;

    // Include the Auth string in the headers
    // Together with the API version being used
    $headers = array(
    "Authorization: GoogleLogin auth=" . $auth,
    "GData-Version: 3.0",
    );

    // Make the request
    $url2 = "https://docs.google.com/feeds/default/private/full";
    $url = "https://docs.google.com//feeds/default/private/full/folder%3A" . $collection_id . "/contents";
    curl_setopt($curl, CURLOPT_URL, $url);
    curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
    curl_setopt($curl, CURLOPT_POST, FALSE);

    $response = curl_exec($curl);
    curl_close($curl);

    // Parse the response
    $response = simplexml_load_string($response);

    // Output data
    $content = "";
    $content .= theme('droogle_list_docs', $response);
    return $content;

}

/*
 * retrieves information about a user from the google api
 * 
 * @param string $username
 *   a string with the username to grab information about
 * 
 * @return array $userArray
 *   returns an array of user information
 */
function droogle_retrieve_user($username) {
 $client = Zend_Gdata_ClientLogin::getHttpClient('username@domain.edu', 'password', Zend_Gdata_Gapps::AUTH_SERVICE_NAME);
 $domain = "babson.edu";
 try {
  $gdata = new Zend_Gdata_Gapps($client, $domain);
 } catch (Exception $e) {
  echo 'Caught exception: ',  $e->getMessage(), "\n";
 }

 $user = $gdata->retrieveUser($username);
 try{
  if (!$user) {
   throw new Exception("ERROR: The user object has no data");
  }
 } catch (Exception $e) {
  echo 'Caught exception: ',  $e->getMessage(), "\n";
  return FALSE;
 }
 $userArray = array();
 $userArray['username'] = $user->login->userName;
 $userArray['givenname'] = $user->name->givenName;
 $userArray['familyname'] = $user->name->familyName;
 $userArray['suspended'] = $user->login->suspended ? 'Yes' : 'No';
 $userArray['admin'] = $user->login->admin ? 'Yes' : 'No';
 $userArray['changePasswordAtNextLogin'] = $user->login->changePasswordAtNextLogin ? 'Yes' : 'No';
 $userArray['agreedToTerms'] = $user->login->agreedToTerms ? 'Yes' : 'No';

 /*echo 'Username: ' . $user->login->userName . "\n";
  echo 'Given Name: ' . $user->name->givenName . "\n";
  echo 'Family Name: ' . $user->name->familyName . "\n";
  echo 'Suspended: ' . ($user->login->suspended ? 'Yes' : 'No') . "\n";
  echo 'Admin: ' . ($user->login->admin ? 'Yes' : 'No') . "\n";
  echo 'Must Change Password: ' . ($user->login->changePasswordAtNextLogin ? 'Yes' : 'No') . "\n";
  echo 'Has Agreed To Terms: ' . ($user->login->agreedToTerms ? 'Yes' : 'No') . "\n";*/
 //print_r($userArray);

 return $userArray;

}

/*
 * a wrapper to invoke the google api to change a users password
 * 
 *  @param string $username
 *    string with the username whos password you want to change
 *  @param string $newuserpassword
 *    string with the new password that will be set
 *  
 *  @return boolean
 *    returns TRUE upon success
 */
function droogle_change_password($username, $newuserpassword) {
 $client = Zend_Gdata_ClientLogin::getHttpClient('username@domain.edu', 'password', Zend_Gdata_Gapps::AUTH_SERVICE_NAME);
 $domain = "babson.edu";
 try {
  $gdata = new Zend_Gdata_Gapps($client, $domain);
 } catch (Exception $e) {
  echo 'Caught exception: ',  $e->getMessage(), "\n";
 }

 //Now change the user's password
 $updateUser = $gdata->retrieveUser($username);
 try {
  if (!$updateUser) {
   throw new Exception("ERROR: The updateUser object has no data");
  }
 } catch (Exception $e) {
  echo 'Caught exception: ',  $e->getMessage(), "\n";
  return FALSE;
 }
 //echo 'Username: ' . $updateUser->login->userName . "\n";
 //echo 'Given Name: ' . $updateUser->name->givenName . "\n";
 //echo 'Family Name: ' . $updateUser->name->familyName . "\n";
 //echo 'Suspended: ' . ($updateUser->login->suspended ? 'Yes' : 'No') . "\n";
 //echo 'Admin: ' . ($updateUser->login->admin ? 'Yes' : 'No') . "\n";
 //echo 'Must Change Password: ' . ($updateUser->login->changePasswordAtNextLogin ? 'Yes' : 'No') . "\n";
 //echo 'Has Agreed To Terms: ' . ($updateUser->login->agreedToTerms ? 'Yes' : 'No') . "\n";
 $updateUser->login->password = $newuserpassword;
 $updateUser = $updateUser->save();


 return TRUE;

}

/*
 * wrapper to create a new google user via the google api
 * 
 * @param string $username
 *   a string with the username to be created
 * @param string $givenname
 *   a string with the users first name
 * @param string $familyname
 *   a string with the users last name
 * @param string $password
 *   a string with the new users password
 *   
 * @return boolean
 *   returns true if a user is successfully created
 */
function droogle_create_user($username, $givenname, $familyname, $password) {
 $client = Zend_Gdata_ClientLogin::getHttpClient('username@domain.edu', 'password', Zend_Gdata_Gapps::AUTH_SERVICE_NAME);
 $domain = "babson.edu";
 try {
  $gdata = new Zend_Gdata_Gapps($client, $domain);
 } catch (Exception $e) {
  echo 'Caught exception: ',  $e->getMessage(), "\n";
 }

 //Now try creating a user
 try {
  $gdata->createUser($username, $givenname, $familyname, $password);
 } catch (Exception $e) {
  echo 'Caught exception: ',  $e->getMessage(), "\n";
  return FALSE;
 }

 return TRUE;

}

/*
 * a wrapper to create a google user via their api
 * 
 * @param string $username
 *   a string with the username to be deleted from google
 *   
 * @return boolean
 *   returns true upon successful deletion of the user
 */
function droogle_delete_user($username) {
 $client = Zend_Gdata_ClientLogin::getHttpClient('username@domain.edu', 'password', Zend_Gdata_Gapps::AUTH_SERVICE_NAME);
 $domain = "babson.edu";
 try {
  $gdata = new Zend_Gdata_Gapps($client, $domain);
 } catch (Exception $e) {
  echo 'Caught exception: ',  $e->getMessage(), "\n";
 }

 //Now try creating a user
 $user = $gdata->retrieveUser($username);
 try {
  if (!$user) {
   throw new Exception("ERROR: The updateUser object has no data");
  }
 } catch (Exception $e) {
  echo 'Caught exception: ',  $e->getMessage(), "\n";
  return FALSE;
 }
 $user->delete();


 return TRUE;

}

/*
 * retrieves all users from a given google domain
 * 
 * TODO:  params are hardcoded currently
 */
function droogle_retrieve_all_users() {
 $client = Zend_Gdata_ClientLogin::getHttpClient('username@domain.edu', 'password', Zend_Gdata_Gapps::AUTH_SERVICE_NAME);
 $domain = "babson.edu";
 try {
  $gdata = new Zend_Gdata_Gapps($client, $domain);
 } catch (Exception $e) {
  echo 'Caught exception: ',  $e->getMessage(), "\n";
 }

 $feed = $gdata->retrieveAllUsers();
 $count = 0;
 foreach ($feed as $user) {
  $count++;
  echo "  * " . $user->login->username . ' (' . $user->name->givenName .
        ' ' . $user->name->familyName . ")\n";
 }
 echo 'total number of users: ' . $count;
}

/*
 * get the collection id for a collection (google folder)
 * 
 * @param string $user
 *   a string with the google username
 * @param string $password
 *   a string with the google password
 * @param string $desiredCollectionTitle
 *   a string with the english name of the folder which youll get an id for
 *  
 * @return string $collectionID
 *   returns a string with the collectionID
 */
function droogle_get_a_collection_id($user, $password, $desiredCollectionTitle) {
 //feeds/default/private/full/-/folder
 // Construct an HTTP POST request
 $clientAcl = droogle_get_client_login_http_client($user, $password);
 $method = 'GET';
 $headers['GData-Version'] = '3.0';
 $contenttype = 'application/atom+xml';

 //This url can be hardcoded or, as in this example, can be dynamically run via a var $docId and $user for sharing
 //$aclUrl = 'http://docs.google.com/feeds/default/private/full/spreadsheet%3A' . $docId . '/acl';
 //$document_id = '1-qYaniUyBYDPNMIos2Rs60RPruYKv17qzRG8mjR-V88';
 //$document_id = '1mKjGghPEU2hfcoU82gPPXT2G0wkBPrIQtPch01-X3BA';  //get this id by clicking on a url on the droogle page and grab the document id

 //api guide:  http://code.google.com/apis/documents/docs/3.0/developers_guide_protocol.html
 //to share a collection http://code.google.com/apis/documents/docs/3.0/developers_guide_protocol.html#ACLSharingCollections
 //by default user will be emailed they have been granted access ... to suppress the email
 // use POST /feeds/default/private/full/document:12345/acl?send-notification-emails=false
 $Url = "https://docs.google.com/feeds/default/private/full/-/folder";
 $Entry = NULL;
 $gdataAcl = new Zend_Gdata($clientAcl);

 try {
  $response = $gdataAcl->performHttpRequest( $method, $Url, $headers, $Entry, $contenttype );
 } catch (Zend_Gdata_App_Exception $ex) {
  // Report the exception to the user
  echo $ex->getMessage();
 }
 /*http://www.welmers.net/~bastiaan/ZendFramework-1.5.3/documentation/manual/core/en/zend.http.response.html
  * this url shows how to parse the results
  */
 $body = $response->getBody();
 $xml = simplexml_load_string($body);
 //$docurl = droogle_xml_attribute($xml->entry->content,'src');
 //preg_match("/folder%3A(.*)\/contents/i", $docurl, $matches);
 //$collectionID = $matches[1];
 $collectionID = "";
 $collectionTitles = "";
 $resultArray = array();
 //print_r($xml->entry);
 foreach ($xml->entry as $object) {
  if ($object->title != $desiredCollectionTitle) {
   continue;
  }
  $collectionTitle = $object->title;
  $docurl = droogle_xml_attribute($object->content, 'src');
  preg_match("/folder%3A(.*)\/contents/i", $docurl, $matches);
  $collectionID = $matches[1];
  //$resultArray[$collectionTitle] = $collectionID;*/
  //$collectionTitles .= $object->title.',';
  //$collectionTitles .= droogle_xml_attribute($object->content,'src');
 }
 //$collectionTitles .= ','.$collectionID;
 return $collectionID;
}

/*
 * helper function getting an attribute
 * 
 * @param object $object
 * @param string $attribute
 * 
 * @return string 
 *   returns a string with the attribute
 */
function droogle_xml_attribute($object, $attribute) {
 if (isset($object[$attribute]))
 return (string) $object[$attribute];
}

